Method: Hubspot::Crm::LineItems::BatchInputSimplePublicObjectId#initialize
- Defined in:
- lib/hubspot/codegen/crm/line_items/models/batch_input_simple_public_object_id.rb
#initialize(attributes = {}) ⇒ BatchInputSimplePublicObjectId
Initializes the object
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/hubspot/codegen/crm/line_items/models/batch_input_simple_public_object_id.rb', line 43 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Hubspot::Crm::LineItems::BatchInputSimplePublicObjectId` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Hubspot::Crm::LineItems::BatchInputSimplePublicObjectId`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'inputs') if (value = attributes[:'inputs']).is_a?(Array) self.inputs = value end end end |